============
Installation
============

**Recommended:** Install with ``pipsi`` in order to use ``remarker`` as a standalone command::

First, `install pipsi <https://github.com/mitsuhiko/pipsi>`_.

Then::

    $ pipsi install Remarker
    
Or, to install in your active Python environment::

    $ pip install Remarker
